==> qmmp_0.7.3.orig.tar.gz: qmmp-0.7.3/src/plugins/General/statusicon/translations/statusicon_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Ustawienia wtyczki Ikona Statusu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>Podpowiedź</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>Opóźnienie, ms:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>Pokaż dymek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>Pokaż pasek postępu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Przezroczystość:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation>Edytuj szablon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>Próbuj rozdzielić nazwę pliku jeśli brakuje tagu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Wielkość okładki:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>Użyj standardowych ikon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Tooltip Template</source>
        <translation>Szablon podpowiedzi</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="65"/>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="66"/>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="67"/>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="69"/>
        <source>Next</source>
        <translation>Następny</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="70"/>
        <source>Previous</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="126"/>
        <source>Now Playing</source>
        <translation>Teraz odtwarza</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Wtyczka Ikona Statusu</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>O Wtyczce Ikona Statusu</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Wtyczka Ikona Statusu dla Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Written by:</source>
        <translation>Napisana przez:</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StatusIconPopupWidget</name>
    <message>
        <location filename="../statusiconpopupwidget.cpp" line="135"/>
        <source>Stopped</source>
        <translation>Zatrzymane</translation>
    </message>
</context>
</TS>

==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/General/statusicon/translations/statusicon_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Ustawienia wtyczki Ikona Statusu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>Pokaż dymek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>Opóźnienie, ms:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>Podpowiedź</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>Próbuj rozdzielić nazwę pliku jeśli brakuje tagu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>Pokaż pasek postępu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Przezroczystość:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Wielkość okładki:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation>Edytuj szablon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>Użyj standardowych ikon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation>Szablon podpowiedzi</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="67"/>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="68"/>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="69"/>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Next</source>
        <translation>Następny</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Previous</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="74"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="129"/>
        <source>Now Playing</source>
        <translation>Teraz odtwarza</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Wtyczka Ikona Statusu</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>O Wtyczce Ikona Statusu</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Wtyczka Ikona Statusu dla Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Written by:</source>
        <translation>Napisana przez:</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIconPopupWidget</name>
    <message>
        <location filename="../statusiconpopupwidget.cpp" line="135"/>
        <source>Stopped</source>
        <translation>Zatrzymane</translation>
    </message>
</context>
</TS>
